@@ -1,8 +1,4 @@
-/* $Id: eval.cc 1462 2007-12-18 20:49:56Z holger $
- *
- * HoiChess/chess/eval.cc
- *
- * Copyright (C) 2004-2006 Holger Ruckdeschel <holger@hoicher.de>
+/* Copyright (C) 2004-2008 Holger Ruckdeschel <holger@hoicher.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -288,7 +284,7 @@ int Evaluator::score_pawns(Color side)
 
 		/* Positional score */
 		const Square idx = (side == WHITE) ? sq
-			: SQUARE(XRANK(RNK(sq)),FIL(sq));
+			: SQUARE(XRNK(RNK(sq)),FIL(sq));
 		if (phase == ENDGAME) {
 			score += pawn_scores_endgame[idx];
 		} else if (phase == MIDGAME) {
@@ -445,6 +441,7 @@ int Evaluator::score_bishops(Color side)
  */
 
 #define EVAL_ROOKMOBILITY	2
+#define EVAL_EARLYROOKADVANCE	-10
 #define EVAL_ROOKOPENFILE	10
 #define EVAL_ROOKHALFOPENFILE	5
 #define EVAL_ROOK7PAWNS7	20	// FIXME too high?
@@ -458,6 +455,7 @@ int Evaluator::score_rooks(Color side)
 	int score = 0;
 
 	const Color xside = XSIDE(side);
+	const int rank1 = (side == WHITE) ? RANK1 : RANK8;
 	const int rank7 = (side == WHITE) ? RANK7 : RANK2;
 	const int rank8 = (side == WHITE) ? RANK8 : RANK1;
 
@@ -473,7 +471,16 @@ int Evaluator::score_rooks(Color side)
 				& ~board->get_pieces(side);
 		score += ra.popcnt() * EVAL_ROOKMOBILITY;
 #endif
-		
+
+#ifdef EVAL_EARLYROOKADVANCE
+		/* Keep rooks on back rank until endgame */
+		if (phase != ENDGAME) {
+			if (RNK(sq) != rank1) {
+				score += EVAL_EARLYROOKADVANCE;
+			}
+		}
+#endif
+
 #if defined(EVAL_ROOKOPENFILE) && defined(EVAL_ROOKHALFOPENFILE)
 		/* Rook on open/half-open file */
 		if (! (Bitboard::file[FIL(sq)] & board->get_pawns(side)) ) {
@@ -601,6 +608,7 @@ int Evaluator::score_queens(Color side)
  * King evaluation.
  */
 
+#define EVAL_KINGPAWNSHIELD 8
 //#define EVAL_SQAROUNDKINGATKD	-4
 
 int Evaluator::score_king(Color side)
@@ -615,6 +623,26 @@ int Evaluator::score_king(Color side)
 		score += king_scores[kingsq];
 	}
 
+#ifdef EVAL_KINGPAWNSHIELD
+	/* Pawn shield */
+	if (phase != ENDGAME) {
+		static const Bitboard kingmask[2] = {
+			/* A1,B1,C1,F1,G1,H1   A8,B8,C8,F8,G8,H8 */
+			0x00000000000000e7ULL, 0xe700000000000000ULL
+		};
+		static const Bitboard pawnmask[2] = {
+			/* A2,B2,C2,F2,G2,H2   A7,B7,C7,F7,G7,H7 */
+			0x000000000000e700ULL, 0x00e7000000000000ULL
+		};
+
+		if (board->get_kings(side) & kingmask[side]) {
+			Bitboard pawnshield = board->king_attacks(kingsq)
+				& pawnmask[side] & board->get_pawns(side);
+			score += pawnshield.popcnt() * EVAL_KINGPAWNSHIELD;
+		}
+	}
+#endif // EVAL_KINGPAWNSHIELD
+
 #ifdef EVAL_SQAROUNDKINGATKD
 	/* Enemy pieces attacking squares around king */
 	Bitboard attackers = NULLBITBOARD;
@@ -626,7 +654,7 @@ int Evaluator::score_king(Color side)
 		attackers |= board->attackers(sq, XSIDE(side));
 	}
 	score += attackers.popcnt() * EVAL_SQAROUNDKINGATKD;
-#endif
+#endif // EVAL_SQAROUNDKINGATKD
 
 	return score;
 }
