@@ -48,11 +48,9 @@ class Evaluator
 	PawnHashTable * pawnhashtable;
 	EvaluationCache * evalcache;
 
-#ifdef COLLECT_STATISTICS
 	unsigned long stat_evals;
 	unsigned long stat_evals_phase1;
 	unsigned long stat_evals_phase2;
-#endif
 
       private:
 	const Board * board;
