@@ -24,11 +24,7 @@
 
 #ifndef PROGNAME
 # if defined(HOICHESS)
-#  ifdef VHDLCHESS
-#   define PROGNAME	"VHoiDLChess"
-#  else
-#   define PROGNAME	"HoiChess"
-#  endif
+#  define PROGNAME	"HoiChess"
 # elif defined(HOIXIANGQI)
 #  define PROGNAME	"HoiXiangqi"
 # else
@@ -121,12 +117,6 @@ extern unsigned int uint64_table_size;
  * Miscellaneous
  */
 
-#ifdef COLLECT_STATISTICS
-# define STAT_INC(x) ((x)++)
-#else
-# define STAT_INC(x)
-#endif
-
 #define INFO_PRFX "Info: "
 
 #endif // COMMON_H
