@@ -35,7 +35,6 @@ EvaluationCache::EvaluationCache(size_t bytes)
 	for (unsigned long i = 0; i < cache_size; i++) {
 		cache[i].score = INT_MIN;
 	}
-	entries = 0;
 
 	reset_statistics();
 }
@@ -52,7 +51,6 @@ void EvaluationCache::clear()
 	for (unsigned long i = 0; i < cache_size; i++) {
 		cache[i].score = INT_MIN;
 	}
-	entries = 0;
 
 	reset_statistics();
 }
@@ -62,13 +60,6 @@ bool EvaluationCache::put(const Board & board, int score)
 	const Hashkey hashkey = board.get_hashkey_noside();
 	const unsigned long key = hashkey % cache_size;
 
-	/* We use an always replace strategy. */
-	if (cache[key].score == INT_MIN) {
-		entries++;
-	} else if (cache[key].hashkey != hashkey) {
-		STAT_INC(stat_collisions);
-	}
-
 	cache[key].hashkey = hashkey;
 	cache[key].score = (board.get_side() == WHITE) ? score : -score;
 	return true;
@@ -77,7 +68,7 @@ bool EvaluationCache::put(const Board & board, int score)
 bool EvaluationCache::probe(const Board & board, int * score)
 {
 	ASSERT(score != NULL);
-	STAT_INC(stat_probes);
+	stat_probes++;
 	
 	const Hashkey hashkey = board.get_hashkey_noside();
 	const unsigned long key = hashkey % cache_size;
@@ -90,62 +81,26 @@ bool EvaluationCache::probe(const Board & board, int * score)
 
 	*score = (board.get_side() == WHITE)
 		? cache[key].score : -cache[key].score;
-	STAT_INC(stat_hits);
+	stat_hits++;
 	return true;
 }
 
 void EvaluationCache::print_info(FILE * fp) const
 {
-#if 0
-	fprintf(fp, "Evaluation cache size: %lu entries (%.1f MiB)\n",
-			cache_size,
-			(float) cache_size * SIZEOF_ENTRY / (1<<20));
-	fprintf(fp, "Evaluation cache usage: %lu entries (%lu%%)\n",
-			entries,
-			entries*100/cache_size);
-#else
 	fprintf(fp, INFO_PRFX "evalcache_size_entries=%lu"
 				" evalcache_size_bytes=%lu\n",
 			cache_size,
 			(unsigned long) (cache_size * sizeof(cacheentry)));
-#endif
 }
 
 void EvaluationCache::print_statistics(FILE * fp) const
 {
-#if 0
-	fprintf(fp, "Evaluation cache entries: %lu (%lu%% full)\n",
-			entries, entries*100/cache_size);
-#else
-	fprintf(fp, INFO_PRFX "evalcache_usage_entries=%lu\n",
-			entries);
-#endif
-
-#ifdef COLLECT_STATISTICS
-#if 0
-	if (stat_probes > 0) {
-		fprintf(fp,
-			"Evaluation cache probes: %lu, hits: %lu (%lu%%)\n",
-			stat_probes,
-			stat_hits,
-			stat_hits*100/stat_probes);
-	}
-	fprintf(fp, "Evaluation cache collisions: %lu\n",
-			stat_collisions);
-#else
-	fprintf(fp, INFO_PRFX "evalcache_probes=%lu evalcache_hits=%lu"
-					" evalcache_collisions=%lu\n",
-			stat_probes, stat_hits,
-			stat_collisions);
-#endif
-#endif // COLLECT_STATISTICS
+	fprintf(fp, INFO_PRFX "evalcache_probes=%lu evalcache_hits=%lu\n",
+			stat_probes, stat_hits);
 }
 
 void EvaluationCache::reset_statistics()
 {
-#ifdef COLLECT_STATISTICS
 	stat_probes = 0;
 	stat_hits = 0;
-	stat_collisions = 0;
-#endif // COLLECT_STATISTICS
 }
