@@ -36,13 +36,8 @@ class EvaluationCache
 	unsigned long cache_size;
 	struct cacheentry * cache;
 	
-	unsigned long entries;
-
-#ifdef COLLECT_STATISTICS
 	unsigned long stat_probes;
 	unsigned long stat_hits;
-	unsigned long stat_collisions;
-#endif
 
       public:
 	EvaluationCache(size_t bytes);
