@@ -41,6 +41,8 @@ ParallelSearch::ParallelSearch(Shell * shell, unsigned int nthreads)
 	for (unsigned int i=0; i<nthreads; i++) {
 		add_slave(new Search(shell));
 	}
+
+	shared_hashtable = NULL;
 }
 
 ParallelSearch::~ParallelSearch()
@@ -49,6 +51,8 @@ ParallelSearch::~ParallelSearch()
 		delete slaves[i].search;
 		delete slaves[i].nodealloc;
 	}
+
+	delete shared_hashtable;
 }
 
 /*****************************************************************************
@@ -256,7 +260,7 @@ int ParallelSearch::parallel_search(Node * node, unsigned int ply,
 		score = -search(child, ply+1, depth-2-1, 0, -beta, -beta+1);
 		child->free();
 		if (score >= beta) {
-			STAT_INC(stat_nullcut);
+			stat_nullcut++;
 			if (failsoft) {
 				return score;
 			} else {
@@ -356,24 +360,29 @@ int ParallelSearch::parallel_search(Node * node, unsigned int ply,
 			 * not important. */
 			probe_hashtable(child, depth-1, -beta, -alpha, &score);
 
+			/* principal variation search */
+			bool nullwin = (SHOPT(search_parallel_pvs_mode) == 1)
+					/* this is never the first move here */
+				|| (SHOPT(search_parallel_pvs_mode) == 2
+					&& alpha > save_alpha);
+
 			/* start the slave */
 			DBG(1, "start slave %d\n", id);
 			ASSERT(slaves[id].free);
 			slaves[id].free = false;
 			slaves[id].node = child;
-			if (alpha <= save_alpha) { /* no PV move found yet */
-				slaves[id].pvs_nullwin = true;
-				slaves[id].search->start_slave_thread(this,
-						game, clock, mode, myside,
-						child, ply+1, depth-1, extend,
-						-beta, -alpha);
-			} else { /* PV move has already been found */
-				/* PVS: search node with null window */
+			if (nullwin) {
 				slaves[id].pvs_nullwin = true;
 				slaves[id].search->start_slave_thread(this,
 						game, clock, mode, myside,
 						child, ply+1, depth-1, extend,
 						-alpha-1, -alpha);
+			} else {
+				slaves[id].pvs_nullwin = false;
+				slaves[id].search->start_slave_thread(this,
+						game, clock, mode, myside,
+						child, ply+1, depth-1, extend,
+						-beta, -alpha);
 			}
 			slaves[id].calls++;
 		}
@@ -485,10 +494,8 @@ done:
 	add_history(node);
 	add_killer(node);
 
-#ifdef COLLECT_STATISTICS
 	stat_moves_sum += moves;
 	stat_moves_cnt++;
-#endif
 	
 	if (failsoft) {
 		return bestscore;
@@ -582,14 +589,32 @@ void ParallelSearch::set_hash_size(size_t bytes)
 	/* We distribute the given size equally among all slaves
 	 * and the master. */
 	unsigned int nslaves = slaves.size();
-	size_t bytes1 = bytes / (nslaves + 1);
+	size_t bytes_master = bytes / (nslaves + 1);
+	size_t bytes_slave = bytes_master;
+	size_t bytes_slave_shared = bytes - bytes_master;
+
+	/* master */
 	if (SHOPT(search_parallel_hash_pvtable)) {
-		Search::set_hash_size_pvline(bytes1);
+		Search::set_hash_size_pvline(bytes_master);
 	} else {
-		Search::set_hash_size(bytes1);
+		Search::set_hash_size(bytes_master);
 	}
-	for (unsigned int i=0; i<nslaves; i++) {
-		slaves[i].search->set_hash_size(bytes1);
+
+	/* slaves */
+	if (SHOPT(search_parallel_shared_hash)) {
+		delete shared_hashtable;
+		shared_hashtable = new HashTable(bytes_slave_shared);
+
+		for (unsigned int i=0; i<nslaves; i++) {
+			slaves[i].search->set_hash_table(shared_hashtable);
+		}
+	} else {
+		delete shared_hashtable;
+		shared_hashtable = NULL;
+
+		for (unsigned int i=0; i<nslaves; i++) {
+			slaves[i].search->set_hash_size(bytes_slave);
+		}
 	}
 }
 
