@@ -38,7 +38,6 @@ PawnHashTable::PawnHashTable(size_t bytes)
 	}
 
 	table = new PawnHashEntry[table_size];
-	entries = 0;
 
 	reset_statistics();
 }
@@ -52,7 +51,6 @@ void PawnHashTable::clear()
 {
 	delete[] table;
 	table = new PawnHashEntry[table_size];
-	entries = 0;
 
 	reset_statistics();
 }
@@ -60,16 +58,6 @@ void PawnHashTable::clear()
 bool PawnHashTable::put(const PawnHashEntry & entry)
 {
 	const unsigned long key = entry.hashkey % table_size;
-	const PawnHashEntry & e = table[key];
-
-	if (e.phase == -1) {
-		entries++;
-	} else {
-		/* Always replace. */
-		if (e.hashkey != entry.hashkey) {
-			STAT_INC(stat_collisions);
-		}
-	}
 
 	table[key] = entry;
 	return true;
@@ -77,7 +65,7 @@ bool PawnHashTable::put(const PawnHashEntry & entry)
 
 bool PawnHashTable::probe(Hashkey hashkey, PawnHashEntry * entry)
 {
-	STAT_INC(stat_probes);
+	stat_probes++;
 
 	const unsigned long key = hashkey % table_size;
 	const PawnHashEntry & e = table[key];
@@ -88,66 +76,28 @@ bool PawnHashTable::probe(Hashkey hashkey, PawnHashEntry * entry)
 	}
 
 	*entry = e;
-	STAT_INC(stat_hits);
+	stat_hits++;
 	return true;
 }
 
 void PawnHashTable::print_info(FILE * fp) const
 {
-#if 0
-	fprintf(fp, "Pawn hash table size: %lu entries (%.1f MiB)\n",
-			table_size,
-			(float) table_size * sizeof(PawnHashEntry) / (1<<20));
-	fprintf(fp, "Pawn hash table usage: %lu entries (%lu%%)\n",
-			entries,
-			entries*100/table_size);
-#else
 	fprintf(fp, INFO_PRFX "pawnhash_size_entries=%lu"
 						" pawnhash_size_bytes=%lu\n",
 			table_size,
 			(unsigned long) (table_size * sizeof(PawnHashEntry)));
-#endif
 }
 
 void PawnHashTable::print_statistics(FILE * fp) const
 {
-#if 0
-	fprintf(fp, "Pawn hash table entries: %lu (%lu%% full)\n",
-			entries, entries*100/table_size);
-#else
-	fprintf(fp, INFO_PRFX "pawnhash_usage_entries=%lu\n",
-			entries);
-#endif
-
-#ifdef COLLECT_STATISTICS
-#if 0
-	if (stat_probes > 0) {
-		fprintf(fp,
-			"Pawn hash table probes: %lu, hits: %lu/%lu"
-			" (%lu%%/%lu%%)\n",
-			stat_probes,
-			stat_hits, stat_hits2,
-			stat_hits*100/stat_probes, stat_hits2*100/stat_probes);
-	}
-	fprintf(fp, "Pawn hash table collisions: %lu\n",
-			stat_collisions);
-#else
 	fprintf(fp, INFO_PRFX "pawnhash_probes=%lu"
-			" pawnhash_hits=%lu pawnhash_hits2=%lu"
-			" pawnhash_collisions=%lu\n",
-			stat_probes, 
-			stat_hits, stat_hits2,
-			stat_collisions);
-#endif
-#endif // COLLECT_STATISTICS
+			" pawnhash_hits=%lu pawnhash_hits2=%lu\n",
+			stat_probes, stat_hits, stat_hits2);
 }
 
 void PawnHashTable::reset_statistics()
 {
-#ifdef COLLECT_STATISTICS
 	stat_probes = 0;
 	stat_hits = 0;
 	stat_hits2 = 0;
-	stat_collisions = 0;
-#endif // COLLECT_STATISTICS
 }
