@@ -44,6 +44,7 @@ Search::Search(Shell * shell)
 
 	evaluator = new Evaluator();
 	hashtable = NULL;
+	shared_hashtable = false;
 	histtable[WHITE] = new HistoryTable();
 	histtable[BLACK] = new HistoryTable();
 
@@ -64,7 +65,9 @@ Search::Search(Shell * shell)
 Search::~Search()
 {
 	delete evaluator;
-	delete hashtable;
+	if (!shared_hashtable) {
+		delete hashtable;
+	}
 	delete histtable[WHITE];
 	delete histtable[BLACK]; 
 }
@@ -550,6 +553,7 @@ int Search::search_root(Node * node, unsigned int ply, int depth,
 	int score;
 	int bestscore = -INFTY;
 	int moves = 0;
+	bool first = true;
 	for (Move mov = node->first(); mov; mov = node->next()) {
 		/* make move */
 		Node * child = node->make_move(mov, &nodealloc);
@@ -569,17 +573,20 @@ int Search::search_root(Node * node, unsigned int ply, int depth,
 
 		/* Search the current move. We use a standard
 		 * principal variation search here. */
-		if (alpha <= save_alpha) { /* no PV move found yet */
-			score = -search(child, ply+1, depth-1, 0,
-					-beta, -alpha);
-		} else { /* PV move has already been found */
+		bool nullwin = (SHOPT(search_pvs_mode) == 1 && !first)
+			|| (SHOPT(search_pvs_mode) == 2 && alpha > save_alpha);
+		if (nullwin) {
 			score = -search(child, ply+1, depth-1, 0,
 					-alpha-1, -alpha);
 			if (score > alpha && score < beta) {
-				score = -search(child, ply+1, depth-1, 0, 
+				score = -search(child, ply+1, depth-1, 0,
 						-beta, -alpha);
 			}			
+		} else {
+			score = -search(child, ply+1, depth-1, 0,
+					-beta, -alpha);
 		}
+		first = false;
 
 		if (!failsoft && (score < alpha || score > beta) && !stop) {
 			printf("search_root(): fail hard condition violated:"
@@ -619,17 +626,15 @@ int Search::search_root(Node * node, unsigned int ply, int depth,
 			if (!failsoft) {
 				score = beta; /* fail hard */
 			}
-			STAT_INC(stat_cut);
+			stat_cut++;
 			break;
 		}
 	}
 	
 	add_history(node);
 
-#ifdef COLLECT_STATISTICS
 	stat_moves_sum += moves;
 	stat_moves_cnt++;
-#endif
 
 	if (failsoft) {
 		return bestscore;
@@ -659,6 +664,7 @@ int Search::search(Node * node, unsigned int ply, int depth, int extend,
 	int score;
 	int bestscore = -INFTY;
 	int moves = 0;
+	bool first = true;
 	nodes_fullwidth++;
 	
 	if (ply > maxplyreached_fullwidth) {
@@ -678,7 +684,7 @@ int Search::search(Node * node, unsigned int ply, int depth, int extend,
 		score = -search(child, ply+1, depth-2-1, 0, -beta, -beta+1);
 		child->free();
 		if (score >= beta) {
-			STAT_INC(stat_nullcut);
+			stat_nullcut++;
 			if (failsoft) {
 				return score;
 			} else {
@@ -705,25 +711,22 @@ int Search::search(Node * node, unsigned int ply, int depth, int extend,
 	/*
 	 * Futility pruning, extended futility pruning, and razoring.
 	 */
-#ifdef USE_RAZORING
 	if (depth == 3  &&  (node->material_balance() + 900 <= alpha)) {
-		STAT_INC(stat_razcut);
+		/* razoring */
+		stat_razcut++;
 		depth--;
 	}
-#endif // USE_RAZORING
 
-#ifdef USE_FUTILITYPRUNING
 	bool fprune = false;
 	if (depth == 1  &&  (node->material_balance() + 300 <= alpha)) {
+		/* futility pruning */
 		fprune = true;
-#ifdef USE_EXTENDED_FUTILITYPRUNING
 	} else if (depth == 2  &&  (node->material_balance() + 500 <= alpha)) {
-		STAT_INC(stat_xfutcut);
+		/* extended futility pruning */
+		stat_xfutcut++;
 		fprune = true;
 		depth--;
-#endif // USE_EXTENDED_FUTILITYPRUNING
 	}
-#endif // USE_FUTILITYPRUNING
 
 	/*
 	 * Search all successor moves.
@@ -736,7 +739,6 @@ int Search::search(Node * node, unsigned int ply, int depth, int extend,
 		}
 		moves++;
 
-#ifdef USE_FUTILITYPRUNING
 		/* Futility pruning */
 		if (fprune && !node->in_check() && !child->in_check()
 				&& !mov.is_capture()
@@ -745,25 +747,28 @@ int Search::search(Node * node, unsigned int ply, int depth, int extend,
 				&& !mov.is_promotion()
 #endif // HOICHESS
 				) {
-			STAT_INC(stat_futcut);
+			stat_futcut++;
 			child->free();
 			continue;
 		}
-#endif // USE_FUTILITYPRUNING
+
 
 		/* Search the current move. We use a standard
 		 * principal variation search here. */
-		if (alpha <= save_alpha) { /* no PV move found yet */
-			score = -search(child, ply+1, depth-1, extend,
-					-beta, -alpha);
-		} else { /* PV move has already been found */
+		bool nullwin = (SHOPT(search_pvs_mode) == 1 && !first)
+			|| (SHOPT(search_pvs_mode) == 2 && alpha > save_alpha);
+		if (nullwin) {
 			score = -search(child, ply+1, depth-1, extend,
 					-alpha-1, -alpha);
 			if (score > alpha && score < beta) {
 				score = -search(child, ply+1, depth-1, extend,
 						-beta, -alpha);
 			}			
+		} else {
+			score = -search(child, ply+1, depth-1, extend,
+					-beta, -alpha);
 		}
+		first = false;
 
 		if (!failsoft && (score < alpha || score > beta) && !stop) {
 			printf("search(): fail hard condition violated:"
@@ -797,7 +802,7 @@ int Search::search(Node * node, unsigned int ply, int depth, int extend,
 			if (!failsoft) {
 				score = beta; /* fail hard */
 			}
-			STAT_INC(stat_cut);
+			stat_cut++;
 			break;
 		}
 	}
@@ -828,10 +833,8 @@ int Search::search(Node * node, unsigned int ply, int depth, int extend,
 	add_history(node);
 	add_killer(node);
 
-#ifdef COLLECT_STATISTICS
 	stat_moves_sum += moves;
 	stat_moves_cnt++;
-#endif
 	
 	if (failsoft) {
 		return bestscore;
@@ -929,7 +932,7 @@ int Search::quiescence_search(Node * node, unsigned int ply,
 			if (!failsoft) {
 				score = beta; /* fail hard */
 			}
-			STAT_INC(stat_cut);
+			stat_cut++;
 			break;
 		}
 	}
@@ -951,10 +954,8 @@ int Search::quiescence_search(Node * node, unsigned int ply,
 		store_hashtable(node, 0, save_alpha, beta, alpha);
 	}
 
-#ifdef COLLECT_STATISTICS
 	stat_moves_sum_quiesce += moves;
 	stat_moves_cnt_quiesce++;
-#endif
 	
 	if (failsoft) {
 		return bestscore;
@@ -1082,12 +1083,12 @@ bool Search::probe_hashtable(Node * node, int depth, int alpha, int beta,
 	//struct Node::pvline pvline;
 	struct Node::pvline & pvline = _probe_hashtable_pvline;
 
-	const HashEntry * entry = hashtable->probe(node->get_board(), &pvline);
-	if (!entry) {
+	HashEntry entry;
+	if (!hashtable->probe(node->get_board(), &entry, &pvline)) {
 		return false;
 	}
 
-	node->set_hashmv(entry->get_move());
+	node->set_hashmv(entry.get_move());
 
 	/* Overwrite the node's existing PV line only if the line in the
 	 * hash table is longer. */
@@ -1095,11 +1096,10 @@ bool Search::probe_hashtable(Node * node, int depth, int alpha, int beta,
 		node->set_pvline(pvline);
 	}
 
-	if (entry->get_depth() >= (unsigned) depth) {
-		int s = entry->get_score();
-		switch (entry->get_type()) {
+	if (entry.get_depth() >= (unsigned) depth) {
+		int s = entry.get_score();
+		switch (entry.get_type()) {
 		case HashEntry::EXACT:
-			hashtable->incr_hits2();
 			if (failsoft) {
 				*score = s;
 			} else { /* strict fail hard */
@@ -1108,7 +1108,6 @@ bool Search::probe_hashtable(Node * node, int depth, int alpha, int beta,
 			return true;
 		case HashEntry::ALPHA:
 			if (s <= alpha) {
-				hashtable->incr_hits2();
 				if (failsoft) {
 					*score = s;
 				} else { /* strict fail hard */
@@ -1119,7 +1118,6 @@ bool Search::probe_hashtable(Node * node, int depth, int alpha, int beta,
 			break;
 		case HashEntry::BETA:
 			if (s >= beta) {
-				hashtable->incr_hits2();
 				if (failsoft) {
 					*score = s;
 				} else { /* strict fail hard */
