@@ -117,6 +117,7 @@ class Search
 	NodeAllocator nodealloc;
 	Evaluator * evaluator;
 	HashTable * hashtable;
+	bool shared_hashtable;
 	HistoryTable * histtable[2];
 	
 	/* information about game */
@@ -165,7 +166,6 @@ class Search
 	unsigned long iteration_start_csecs;
 	
       protected:
-#ifdef COLLECT_STATISTICS
 	/* extended statistics */
 	unsigned long stat_cut;
 	unsigned long stat_nullcut;
@@ -176,7 +176,6 @@ class Search
 	unsigned long stat_moves_cnt;
 	unsigned long stat_moves_sum_quiesce;
 	unsigned long stat_moves_cnt_quiesce;
-#endif
 
       private:
 	/* For each ply-1 node, stores the PV of the previous iteration,
@@ -216,6 +215,7 @@ class Search
 
 	virtual void set_hash_size(size_t bytes);
 	virtual void set_hash_size_pvline(size_t bytes);
+	virtual void set_hash_table(HashTable * table);
 	virtual void clear_hash();
 	virtual void set_pawnhash_size(size_t bytes);
 	virtual void clear_pawnhash();
