@@ -50,7 +50,6 @@ void Search::print_statistics()
 			(float) csecs / 100, 
 			nodes_total / ((float) csecs / 100) );
 
-#ifdef COLLECT_STATISTICS
 	printf(INFO_PRFX "cuts_beta=%ld cuts_null=%ld cuts_fut=%ld"
 					" cuts_xfut=%ld cuts_razor=%ld\n",
 			stat_cut, stat_nullcut, stat_futcut,
@@ -59,7 +58,6 @@ void Search::print_statistics()
 					" avg_branchfactor_quiesce=%.2f\n",
 		(float) stat_moves_sum / stat_moves_cnt,
 		(float) stat_moves_sum_quiesce / stat_moves_cnt_quiesce);
-#endif // COLLECT_STATISTICS
 	
 	if (hashtable) {
 		hashtable->print_statistics();
@@ -74,7 +72,6 @@ void Search::reset_statistics()
 	/* maxplyreached_fullwidth and maxplyreached_quiesce are reset
 	 * in iterate() so they can be tracked for each iteration
 	 * separately (matter of taste) */
-#ifdef COLLECT_STATISTICS
 	stat_cut = 0;
 	stat_nullcut = 0;
 	stat_futcut = 0;
@@ -84,7 +81,6 @@ void Search::reset_statistics()
 	stat_moves_cnt = 0;
 	stat_moves_sum_quiesce = 0;
 	stat_moves_cnt_quiesce = 0;
-#endif // COLLECT_STATISTICS
 
 	if (hashtable) {
 		hashtable->reset_statistics();
@@ -193,26 +189,45 @@ void Search::get_root_progress(unsigned int * moves_total,
 
 void Search::set_hash_size(size_t bytes)
 {
-	if (bytes > 0) {
+	if (!shared_hashtable) {
 		delete hashtable;
+	}
+
+	if (bytes > 0) {
 		hashtable = new HashTable(bytes);
 		hashtable->print_info();
 	} else {
-		delete hashtable;
 		hashtable = NULL;
 	}
+
+	shared_hashtable = false;
 }
 
 void Search::set_hash_size_pvline(size_t bytes)
 {
-	if (bytes > 0) {
+	if (!shared_hashtable) {
 		delete hashtable;
+	}
+
+	if (bytes > 0) {
 		hashtable = new HashTable(bytes, true);
 		hashtable->print_info();
 	} else {
-		delete hashtable;
 		hashtable = NULL;
 	}
+
+	shared_hashtable = false;
+}
+
+void Search::set_hash_table(HashTable * table)
+{
+	if (!shared_hashtable) {
+		delete hashtable;
+	}
+
+	hashtable = table;
+	hashtable->print_info();
+	shared_hashtable = true;
 }
 
 void Search::clear_hash()
