@@ -786,19 +786,20 @@ int Shell::cmd_solve()
 				epd.get_fen().c_str());
 
 		/* Get the list of best moves */
-		std::list<std::string> bms = epd.get("bm");
-		std::list<std::string>::const_iterator it;
+		std::list<Move> bms = epd.get_bm();
 		if (bms.size() == 0) {
 			printf("No best move associated to this position,"
 					" skipping.\n");
 			skipped++;
 			continue;
 		}
-		
+
 		/* Print the list of best moves */
 		printf("[%s] best move:", epd.get1("id").c_str());
-		for (it = bms.begin(); it != bms.end(); it++)
-			printf(" %s", it->c_str());
+		for (std::list<Move>::const_iterator it = bms.begin();
+				it != bms.end(); it++) {
+			printf(" %s", it->san(board).c_str());
+		}
 		printf("\n");
 
 		/* Reset search stuff */
@@ -827,25 +828,13 @@ int Shell::cmd_solve()
 			continue;
 		}
 		
-		/* Look if our move is among the best. In addition to the
-		 * EPD standard, which requires SAN, we tolerate a missing
-		 * '+' or '#' at the end, and accept coordinate notation. */
+		/* Look if our move is among the best. */
 		bool correct = false;
+		std::list<Move>::const_iterator it;
 		for (it = bms.begin(); it != bms.end(); it++) {
-			std::string san = mov.san(board);
-			std::string coord = mov.str();
-			bool tol = false; // set as side effect in condition
-			if (*it == san
-				|| (((*it + "+") == san) && (tol = true))
-				|| (((*it + "#") == san) && (tol = true))
-				|| ((*it == coord) && (tol = true)) ) {
+			if (*it == mov) {
 				right++;
 				correct = true;
-				if (tol) {
-					printf("Warning: tolerating"
-						" non-standard 'bm' value"
-						" in EPD: %s\n", it->c_str());
-				}
 				break;
 			}
 		}
@@ -944,35 +933,10 @@ int Shell::cmd_hash()
 	} else if (param == "off") {
 		stop_search();
 		set_hash_size(0);
-#if 0 /* TODO not accessible from here anymore */
-	} else if (param == "info") {
-		if (hashtable) {
-			hashtable->print_info();
-		} else {
-			printf("Hash table is disabled.\n");
-		}
-	} else if (param == "stats") {
-		if (hashtable) {
-			hashtable->print_statistics();
-		} else {
-			printf("Error: hash table is disabled\n");
-		}
-	} else if (param == "replace") {
-		SHELL_CMD_REQUIRE_ARGS(2);
-		if (hashtable) {
-			hashtable->set_replacement_scheme(cmd_args[2]);
-		} else {
-			printf("Error: hash table is disabled\n");
-		}
-#endif
 	} else {
 		printf("Usage: hash clear\n");
 		printf("       hash size <size>\n");
 		printf("       hash off\n");
-#if 0
-		printf("       hash info\n");
-		printf("       hash stats\n");
-#endif
 	}
 
 	return SHELL_CMD_OK;
@@ -999,28 +963,10 @@ int Shell::cmd_pawnhash()
 	} else if (param == "off") {
 		stop_search();
 		set_pawnhash_size(0);
-#if 0 /* TODO not accessible from here anymore */
-	} else if (param == "info") {
-		if (pawnhashtable) {
-			pawnhashtable->print_info();
-		} else {
-			printf("Pawn hash table is disabled.\n");
-		}
-	} else if (param == "stats") {
-		if (pawnhashtable) {
-			pawnhashtable->print_statistics();
-		} else {
-			printf("Error: Pawn hash table is disabled\n");
-		}
-#endif
 	} else {
 		printf("Usage: pawnhash clear\n");
 		printf("       pawnhash size <size>\n");
 		printf("       pawnhash off\n");
-#if 0
-		printf("       pawnhash info\n");
-		printf("       pawnhash stats\n");
-#endif
 	}
 
 	return SHELL_CMD_OK;
@@ -1047,28 +993,10 @@ int Shell::cmd_evalcache()
 	} else if (param == "off") {
 		stop_search();
 		set_evalcache_size(0);
-#if 0 /* TODO not accessible from here anymore */
-	} else if (param == "info") {
-		if (evalcache) {
-			evalcache->print_info();
-		} else {
-			printf("Evaluation cache is disabled.\n");
-		}
-	} else if (param == "stats") {
-		if (evalcache) {
-			evalcache->print_statistics();
-		} else {
-			printf("Error: evaluation cache is disabled\n");
-		}
-#endif
 	} else {
 		printf("Usage: evalcache clear\n");
 		printf("       evalcache size <size>\n");
 		printf("       evalcache off\n");
-#if 0
-		printf("       evalcache info\n");
-		printf("       evalcache stats\n");
-#endif
 	}
 
 	return SHELL_CMD_OK;
