@@ -13,5 +13,8 @@ SHELL_DEFINE_OPTION(search_time_for_new_iteration_expect_factor_tenth, 15);
 SHELL_DEFINE_OPTION(search_parallel_min_depth, 6);
 SHELL_DEFINE_OPTION(search_parallel_min_move_ratio, 2);
 SHELL_DEFINE_OPTION(search_parallel_hash_pvtable, 0);
+SHELL_DEFINE_OPTION(search_parallel_shared_hash, 0);
+SHELL_DEFINE_OPTION(search_parallel_pvs_mode, 1);
 
 SHELL_DEFINE_OPTION(search_failsoft, 0);
+SHELL_DEFINE_OPTION(search_pvs_mode, 1);
