@@ -27,15 +27,6 @@
  * made. */
 //#define USE_UNMAKE_MOVE
 
-/* Use futility pruning */
-#define USE_FUTILITYPRUNING
-
-/* Use extended futility pruning */
-#define USE_EXTENDED_FUTILITYPRUNING
-
-/* Use razoring */
-//#define USE_RAZORING
-
 /* Maximum depth for full-width search */
 #define MAXDEPTH		900
 
@@ -45,7 +36,4 @@
 /* Maximum size of a Movelist */
 #define MOVELIST_MAXSIZE	256
 
-/* Collect statistics, e.g. hash table hits, cutoffs during search, etc. */
-#define COLLECT_STATISTICS
-
 #endif // CONFIG_H
