@@ -37,7 +37,7 @@
 
 
 
-#ifdef USE_THREAD
+#ifdef WITH_THREAD
 /* We cannot include util.h or thread.h, since they may use something
  * that is declared inside this file. */
 class Mutex;
@@ -62,7 +62,7 @@ extern Mutex stdout_mutex;
 
 class __debug_helper {
 	FILE * fp;
-#ifdef USE_THREAD
+#ifdef WITH_THREAD
 	Mutex * mutex;
 #endif
 	const char * file;
@@ -70,12 +70,12 @@ class __debug_helper {
 	const char * function;
       public:
 	inline __debug_helper(FILE * fp, 
-#ifdef USE_THREAD
+#ifdef WITH_THREAD
 			Mutex * mutex,
 #endif
 			const char * file, int line, const char * function)
 		: fp(fp),
-#ifdef USE_THREAD
+#ifdef WITH_THREAD
 		mutex(mutex),
 #endif
 		file(file), line(line), function(function)
@@ -90,7 +90,7 @@ class __debug_helper {
 };
 
 
-#ifdef USE_THREAD
+#ifdef WITH_THREAD
 
 #define DBG __debug_helper(stdout, &stdout_mutex,	\
 		__FILE__, __LINE__, __PRETTY_FUNCTION__).__dbg
@@ -99,7 +99,7 @@ class __debug_helper {
 #define BUG __debug_helper(stderr, NULL,	\
 		__FILE__, __LINE__, __PRETTY_FUNCTION__).__bug
 
-#else // !USE_THREAD
+#else // !WITH_THREAD
 
 #define DBG __debug_helper(stdout, 	\
 		__FILE__, __LINE__, __PRETTY_FUNCTION__).__dbg
@@ -108,7 +108,7 @@ class __debug_helper {
 #define BUG __debug_helper(stderr, 	\
 		__FILE__, __LINE__, __PRETTY_FUNCTION__).__bug
 
-#endif // !USE_THREAD
+#endif // !WITH_THREAD
 
 
 #define ASSERT(expr) do {	\
