@@ -32,15 +32,18 @@
  * SUCH DAMAGE.
  */
 
+extern "C" {
+
 #ifdef WIN32
 #include <windows.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
 #else
 #include <sys/param.h>
 #endif
+#include <stdarg.h>
 #include <stdint.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 /*
 **	SNPRINTF, VSNPRINT -- counted versions of printf
@@ -154,14 +157,14 @@ static void leading_pad(int zpad, int *signvalue, int *padlen, char *end,
 				 char **output);
 static void trailing_pad(int *padlen, char *end, char **output);
 
-static void fmtstr(char *value, int leftjust, int minlen, int maxwidth,
+static void fmtstr(const char *value, int leftjust, int minlen, int maxwidth,
 	   char *end, char **output);
 static void fmtint(int64_t value, int base, int dosign, int forcesign,
 	   int leftjust, int minlen, int zpad, char *end, char **output);
 static void fmtfloat(double value, char type, int forcesign,
 	   int leftjust, int minlen, int zpad, int precision, int pointflag, char *end,
 	   char **output);
-static void dostr(char *str, int cut, char *end, char **output);
+static void dostr(const char *str, int cut, char *end, char **output);
 static void dopr_outch(int c, char *end, char **output);
 
 #define FMTSTR		1
@@ -587,7 +590,7 @@ nochar:
 }
 
 static void
-fmtstr(char *value, int leftjust, int minlen, int maxwidth, char *end,
+fmtstr(const char *value, int leftjust, int minlen, int maxwidth, char *end,
 	   char **output)
 {
 	int			padlen,
@@ -682,7 +685,7 @@ fmtfloat(double value, char type, int forcesign, int leftjust,
 }
 
 static void
-dostr(char *str, int cut, char *end, char **output)
+dostr(const char *str, int cut, char *end, char **output)
 {
 	if (cut)
 		while (*str && cut-- > 0)
@@ -776,3 +779,4 @@ trailing_pad(int *padlen, char *end, char **output)
 	}
 }
 
+} /* extern "C" */
