@@ -1,3 +1,6 @@
+#ifndef SNPRINTF_H
+#define SNPRINTF_H
+
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -14,9 +17,5 @@ extern int pg_printf(const char *fmt, ...);
 
 #define vsnprintf pg_vsnprintf
 #define snprintf pg_snprintf
-#ifdef __leonbare__
-# define sprintf pg_sprintf
-# define fprintf pg_fprintf
-# define printf pg_printf
-#endif
 
+#endif // SNPRINTF_H
