@@ -281,9 +281,7 @@ static void setup_shell(struct opts * opts)
 	 * commands in --source files, because the last opened source is
 	 * read as first */
 	if (!opts->norc) {
-#if defined(VHDLCHESS)
-		const char * rcfile_base = "vhoidlchess.rc";
-#elif defined(HOICHESS)
+#if defined(HOICHESS)
 		const char * rcfile_base = "hoichess.rc";
 #elif defined(HOIXIANGQI)
 		const char * rcfile_base = "hoixiangqi.rc";
