@@ -24,25 +24,30 @@
 Mutex::Mutex()
 {
 #if defined(HAVE_PTHREAD)
-	pthread_mutex_init(&mtx, NULL);
+	int res = pthread_mutex_init(&mtx, NULL);
+	ASSERT(res == 0);
 #elif defined(WIN32)
 	hndl = CreateMutex(NULL, FALSE, NULL);
+	ASSERT(hndl != NULL);
 #endif
 }
 
 Mutex::~Mutex()
 {
 #if defined(HAVE_PTHREAD)
-	pthread_mutex_destroy(&mtx);
+	int res = pthread_mutex_destroy(&mtx);
+	ASSERT(res == 0);
 #elif defined(WIN32)
-	CloseHandle(hndl);
+	BOOL res = CloseHandle(hndl);
+	ASSERT(res);
 #endif
 }
 
 void Mutex::lock()
 {
 #if defined(HAVE_PTHREAD)
-	pthread_mutex_lock(&mtx);
+	int res = pthread_mutex_lock(&mtx);
+	ASSERT(res == 0);
 #elif defined(WIN32)
 	DWORD res = WaitForSingleObject(hndl, INFINITE);
 	ASSERT(res == WAIT_OBJECT_0);
@@ -52,9 +57,10 @@ void Mutex::lock()
 void Mutex::unlock()
 {
 #if defined(HAVE_PTHREAD)
-	pthread_mutex_unlock(&mtx);
+	int res = pthread_mutex_unlock(&mtx);
+	ASSERT(res == 0);
 #elif defined(WIN32)
-	bool res = ReleaseMutex(hndl);
+	BOOL res = ReleaseMutex(hndl);
 	ASSERT(res);
 #endif
 }
