@@ -22,15 +22,11 @@
 #include "common.h"
 
 
-#ifdef USE_THREAD
-# if defined(HAVE_PTHREAD)
-#  include <pthread.h>
-# elif defined(WIN32)
-#  include <windows.h>
-# else
-#  error no thread support is available
-# endif
-#endif /* USE_THREAD */
+#if defined(HAVE_PTHREAD)
+# include <pthread.h>
+#elif defined(WIN32)
+# include <windows.h>
+#endif
 
 
 class Mutex {
