@@ -20,7 +20,7 @@
 #include "common.h"
 #include "util.h"
 #include "signal.h"
-#ifdef USE_THREAD
+#ifdef WITH_THREAD
 # include "mutex.h"
 # include "thread.h"
 #endif
@@ -29,10 +29,15 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifndef WIN32
+# include <sys/time.h>
+# include <sys/times.h>
+#endif
 #include <time.h>
+#include <unistd.h>
 
 
-#ifdef USE_THREAD
+#ifdef WITH_THREAD
 Mutex stdout_mutex;
 
 int atomic_printf(const char * fmt, ...)
@@ -61,7 +66,7 @@ int atomic_fprintf(FILE * fp, Mutex * mutex, const char * fmt, ...)
 	mutex->unlock();
 	return ret;
 }
-#endif // USE_THREAD
+#endif // WITH_THREAD
 
 
 /*
@@ -131,6 +136,58 @@ bool parse_size(const char * s, ssize_t * n)
 	}
 }
 
+/* Returns real time (wall clock) in microseconds since an undefined point
+ * in the past. Use for time measurement. */
+unsigned long long get_realtime_us()
+{
+	unsigned long long t;
+#ifdef WIN32
+	FILETIME ft;
+	GetSystemTimeAsFileTime(&ft);
+	/* resolution is 100 ns */
+	uint64_t tmp = ((uint64_t) ft.dwHighDateTime << 32) | ft.dwLowDateTime;
+	t = tmp / 10;
+#else
+	struct timeval tv;
+	if (gettimeofday(&tv, NULL) == -1) {
+		perror("gettimeofday() failed");
+		exit(EXIT_FAILURE);
+	}
+	t = (unsigned long long) tv.tv_sec * (int)1E6 + tv.tv_usec;
+#endif
+	return t;
+}
+
+#if !defined(WIN32) && !defined(__leonbare__)
+/* FIXME assumes that sysconf() never fails */
+static long sc_clk_tck = sysconf(_SC_CLK_TCK);
+#endif
+
+/* Returns CPU time (user time) in microseconds since an undefined point
+ * in the past. Use for time measurement. */
+unsigned long long get_cputime_us()
+{
+	unsigned long long t;
+#if defined(WIN32)
+	FILETIME ct, et, kt, ut;
+	BOOL ok = GetProcessTimes(GetCurrentProcess(), &ct, &et, &kt, &ut);
+	ASSERT(ok);
+	/* resolution is 100 ns */
+	uint64_t tmp = ((uint64_t) ut.dwHighDateTime << 32) | ut.dwLowDateTime;
+	t = tmp / 10;
+#elif defined(__leonbare__)
+	t = get_realtime_us();
+#else
+	struct tms tmp;
+	if (times(&tmp) == -1) {
+		perror("times() failed");
+		exit(EXIT_FAILURE);
+	}
+	t = (int)1E6 * (unsigned long long) (tmp.tms_utime + tmp.tms_cutime)
+		/ sc_clk_tck;
+#endif
+	return t;
+}
 
 unsigned long long _timing_trace_us_start;
 unsigned long long _timing_trace_us_last;
