@@ -2,6 +2,8 @@
 #define VERSION_H
 
 extern const char * version;
-extern const char * compile_date;
+
+/* disabled for reproducible build */
+//extern const char * compile_date;
 
 #endif 
